Basic usage tutorials
=====================

In the following, you find a number of tutorials that demonstrate the basic capabilities of :code:`py4dgeo`.

.. toctree::

    m3c2
    customization
    registration
    m3c2ep
    4dobc-creation
    4dobc-analysis
    4dobc-customization
    pbm3c2
    hierarchical_change_analysis
    spatial_subsampling
